/*
 * KostenZweierquote.java
 * eu.gronos.kostenrechner.data.forderungen (Kostenrechner)
 */
package eu.gronos.kostenrechner.data;

/**
 * Ein Objekt zur Kostenverteilung, war ein Array double[] mit der Quote des
 * Klägers und des Beklagten, jeweils zwischen 0.0 und 1.0
 *
 * @author Peter Schuster (setrok)
 * @date 07.08.2020
 *
 */
public class KostenZweierquote {
	private final double klaegerQuote;
	private final double beklagtenQuote;

	/**
	 * Konstruktor:
	 * 
	 * @param klaegerQuote   {@link #getKlaegerQuote()}, war kosten[0] mit der Quote
	 *                       des Klägers, zwischen 0.0 und 1.0
	 * @param beklagtenQuote {@link #getBeklagtenQuote()}, war kosten[1] mit der
	 *                       Quote des Beklagten, zwischen 0.0 und 1.0
	 */
	public KostenZweierquote(double klaegerQuote, double beklagtenQuote) {
		this.klaegerQuote = klaegerQuote;
		this.beklagtenQuote = beklagtenQuote;
	}

	/**
	 * Konstruktor:
	 * 
	 * @param klaegerQuote war kosten[0] mit der Quote des Klägers, zwischen 0.0 und
	 *                     1.0, woraus die Klasse auch die
	 *                     {@link #getBeklagtenQuote()} errechnet.
	 */
	public KostenZweierquote(double klaegerQuote) {
		this(klaegerQuote, 1.0 - klaegerQuote);
	}

	/**
	 * @return gibt {@link #klaegerQuote} als {@link double} zurück, war kosten[0]
	 *         mit der Quote des Klägers, zwischen 0.0 und 1.0.
	 */
	public double getKlaegerQuote() {
		return klaegerQuote;
	}

	/**
	 * @return gibt {@link #beklagtenQuote} als {@link double} zurück, war kosten[1]
	 *         mit der Quote des Beklagten, zwischen 0.0 und 1.0.
	 */
	public double getBeklagtenQuote() {
		return beklagtenQuote;
	}

}
