/*
 * BeteiligtenPruefer.java
 * eu.gronos.kostenrechner.util.baumbach (Kostenrechner)
 */
package eu.gronos.kostenrechner.util.baumbach;

import eu.gronos.kostenrechner.data.baumbach.BaumbachBeteiligter;
import eu.gronos.kostenrechner.data.tenordaten.Beteiligter;
import eu.gronos.kostenrechner.interfaces.Pruefend;
import eu.gronos.kostenrechner.view.HinzufuegenDialog;

/**
 * Der {@link Pruefend} kontrolliert alle Werte zum Bau eines
 * {@link Beteiligter}n
 *
 * @author Peter Schuster (setrok)
 * @date 16.07.2020
 *
 */
public class BeteiligtenPruefer implements Pruefend<BaumbachBeteiligter> {

	/**
	 * Die Methode prüft den {@link BaumbachBeteiligter}n
	 * 
	 * @param eingabe der zu prüfende {@link BaumbachBeteiligter}
	 * @return <code>true</code>, wenn alle Plausis eingehalten werden
	 * @throws IllegalArgumentException
	 * @throws NumberFormatException
	 * @throws NullPointerException     TODO
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Pruefend#pruefeEingabe(java.lang.Object)
	 */
	@Override
	public boolean pruefeEingabe(BaumbachBeteiligter eingabe)
			throws IllegalArgumentException, NumberFormatException, NullPointerException {
		if (eingabe.getStreitwert() < eingabe.getUnterliegen())
			throw new NumberFormatException(HinzufuegenDialog.FEHLER_BT_UNTERLIEGEN_GT_STREITWERT);
		if (eingabe.getStreitwert() <= 0.0
				&& (Beteiligter.KLAEGER != eingabe.getTyp() || eingabe.isAnWiderklageBeteiligt()))
			throw new IllegalArgumentException(HinzufuegenDialog.FEHLER_BK_STREITWERT);
		if (Beteiligter.DRITTWIDERBEKLAGTE == eingabe.getTyp() && !eingabe.isAnWiderklageBeteiligt())
			throw new IllegalArgumentException("Ein Drittwiderbeklagter muss widerbeklagt sein!");
		// Ein nicht widerbeklagter Kläger mit Streitwert/Unterliegen > 0 führt zu
		// Fehlern
		if (Beteiligter.KLAEGER == eingabe.getTyp() && !eingabe.isAnWiderklageBeteiligt()
				&& (eingabe.getStreitwert() > 0.0 || eingabe.getUnterliegen() > 0.0))
			throw new IllegalArgumentException(
					"Ein nicht widerbeklagter Kläger darf nicht in Anspruch genommen oder verurteilt werden (Streitwert oder Verurteilung dürfen nicht größer als 0 sein)!");
		return true;
	}

}
